﻿/******************************************************************************
    CallWave VoiceMail Widget

    Copyright (C) 2006 CallWave, Inc.  All Rights Reserved.

 ******************************************************************************/

/******************************************************************************
  SMS_AutoLoginView c'tor

    HTML DOM Dependencies:
        WIDGET_autoLoginViewFrame  - <div>

    Call backs:
        accountHandler
        onGetAccountInfoSucceeded( responseMessage )
        onLoginRequired( statusMessage )

    Globals:
        VM_GetPreference( key )
        VM_SetPreference( key, value )
        EX_Log( message )
        VM_WIDGET_SOURCE
        VM_WIDGET_VERSION
        VM_WIDGET_OS_VERSION

 ******************************************************************************/
function SMS_AutoLoginView( accountHandler, onGetAccountInfoSucceeded, onLoginRequired )
{
    try
    {
        this.m_accountHandler            = accountHandler;
        this.m_onGetAccountInfoSucceeded = onGetAccountInfoSucceeded;
        this.m_onLoginRequired           = onLoginRequired;

        this.m_loginRetryTimer = null;

        var self = this;

        this.m_accountHandler.m_onGetAccountInfoSucceeded = function( responseMessage )
        {
            self.onGetAccountInfoSucceeded( responseMessage );
        };

        this.m_accountHandler.m_onGetAccountInfoFailed    = function( statusMessage )
        {
            self.onGetAccountInfoFailed( statusMessage );
        }
    }
    catch ( e )
    {
        EX_ASSERT_NO_EXCEPTIONS( e, "SMS_AutoLoginView::SMS_AutoLoginView( )" );
    }
}
SMS_AutoLoginView.prototype =
{
    LOGIN_RETRY_INTERVAL_SECONDS         : 20,

    enableRetryTimer:function( )
    {
        try
        {
            this.disableRetryTimer( );

            var self = this;
            var handleGetAccountInfo = function( )
            {
                self.handleGetAccountInfo( );
            };
            this.m_loginRetryTimer = setInterval( handleGetAccountInfo, this.LOGIN_RETRY_INTERVAL_SECONDS * 1000 );
        }
        catch ( e )
        {
            EX_ASSERT_NO_EXCEPTIONS( e, "SMS_AutoLoginView::enableRetryTimer( )" );
        }
    },

    disableRetryTimer:function( )
    {
        if ( this.m_loginRetryTimer != null )
        {
            clearInterval( this.m_loginRetryTimer );
            this.m_loginRetryTimer = null;
        }
    },

    /**************************************************************************
      View repainting methods
     **************************************************************************/

    reset:function( )
    {
        $( "#WIDGET_autoLoginViewFrame" ).hide();
    },

    refresh:function( )
    {
        try
        {
            $( "#WIDGET_autoLoginViewFrame" ).show();
        }
        catch ( e )
        {
            EX_ASSERT_NO_EXCEPTIONS( e, "SMS_AutoLoginView::refresh( )" );
        }
    },

    /**************************************************************************
      GetAccountInfo methods
     **************************************************************************/
    StartAutoLogin:function( )
    {
        try
        {
            // serve this operation to the time out server
            // since Safari doesn't support scheduling asynchronous
            // operations on the main thread during loading.
            var self = this;
            setTimeout( function( )
            {
                self.handleGetAccountInfo( );
            }, 0 );
        }
        catch ( e )
        {
            EX_ASSERT_NO_EXCEPTIONS( e, "SMS_AutoLoginView::StartAutoLogin( )" );
        }
    },

    handleGetAccountInfo:function( )
    {
        try
        {
            this.m_accountHandler.getAccountInfo( VM_GetPreference( PREF_KEY_ACCOUNT ),
                                                  VM_GetPreference( PREF_KEY_U_STRING ) );
        }
        catch ( e )
        {
            EX_Log( "SMS_AutoLoginView::handleGetAccountInfo( ) : Failed to get account info : " + e.message );

            this.enableRetryTimer( );
        }
    },

    onGetAccountInfoSucceeded:function( responseMessage )
    {
        try
        {
            switch ( responseMessage.m_status )
            {
            case MSG_ResponseStatus.SUCCESS:
                {
                    // Disable retry timer
                    this.disableRetryTimer( );
                    this.m_onGetAccountInfoSucceeded( responseMessage );
                    break;
                }

            case MSG_ResponseStatus.GENERAL_ERROR:
            case MSG_ResponseStatus.GETA_LOGIN_FAILURE:
                {
                    // Disable retry timer
                    this.disableRetryTimer( );
                    // Go to the login screen
                    this.m_onLoginRequired( responseMessage.m_statusMsg );

                    break;
                }

            default:
                // Other error
                {
                    // Retry
                    this.enableRetryTimer( );

                    break;
                }
            }
        }
        catch ( e )
        {
            this.enableRetryTimer( );

            EX_Log( "SMS_AutoLoginView::onGetAccountInfoSucceeded( ) : " + e.message );
        }
    },

    onGetAccountInfoFailed:function( statusMessage )
    {
        // Retry
        this.enableRetryTimer( );
    },

    StopRequest:function( )
    {
        this.m_accountHandler.m_getAccountInfoHttpClient.CancelRequest( );
    }
}
